{ config, pkgs, ... }:
{
  imports = [
    ../modules/home-manager/browser.nix
    ../modules/home-manager/code.nix
  ];

  ## Home Manager configuration
  home.stateVersion = "24.05";
  # Let Home Manager install and manage itself.
  programs.home-manager.enable = true;

  ## Basic configuration
  home.username = "remy";
  home.homeDirectory = "/home/remy";

  #home.file.<filepath> = <content>;
  
  ## Utils relevant to this user only
  programs.git = {
    enable = true;
    userName = "Remy Moll";
    userEmail = "me@moll.re";
  };
  
  programs.fish = {
    enable = true;
    # enableCompletion = true;
    plugins = [
      {
        name = "fzf-fish";
        src = pkgs.fetchFromGitHub {
          owner = "PatrickF1";
          repo = "fzf.fish";
          rev = "v10.3";
          sha256 = "sha256-T8KYLA/r/gOKvAivKRoeqIwE2pINlxFQtZJHpOy9GMM=";
        };
      }
      # add others here
    ];
  };

  # sets the "default" shell to fish
  # actually keeps bash as a posix-compliant default but starts fish if the shell is not bash
  # See https://nixos.wiki/wiki/Fish
  programs.bash = {
    initExtra = ''
      if [[ $(${pkgs.procps}/bin/ps --no-header --pid=$PPID --format=comm) != "fish" && -z ''${BASH_EXECUTION_STRING} ]]
      then
        shopt -q login_shell && LOGIN_OPTION='--login' || LOGIN_OPTION=""
        exec ${pkgs.fish}/bin/fish $LOGIN_OPTION
      fi
    '';
  };

  ## Gnome settings
  dconf.settings = {
    # set the keyboard layout to german
    "org/gnome/desktop/input-sources" = {
      sources = "[('xkb', 'de'), ('xkb', 'ch'), ('xkb', 'us')]";
      xkb-options = "['lv3:ralt_switch']";
    };
  };
}
